(*  GREATIS RUNTIME FUSION                               *)
(*  Copyright (C) 2005-2014 Greatis Software             *)
(*                                                       *)
(*  FORM DESIGNER AND OBJECT INSPECTOR ARE REQUIRED      *)
(*  http://www.greatis.com/delphicb/formdes/             *)
(*  http://www.greatis.com/delphicb/objinsp/             *)
(*                                                       *)
(*  http://www.greatis.com/delphicb/runtime/             *)

unit Design;

interface

uses
  Windows, Messages, Forms, SysUtils, IniFiles, Classes, Controls,
  StdCtrls, ExtCtrls, Dialogs, FDMain, CompInsp, Menus, RunFus, ComCtrls,
  Buttons, Mask, DBCtrls;

type

  TfrmDesign = class(TForm)
    cmpFormDesigner: TRFDesigner;
    procedure FormShow(Sender: TObject);
    procedure cmpFormDesignerSelectControl(Sender: TObject;
      TheControl: TControl);
    procedure FormActivate(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure cmpFormDesignerControlDblClick(Sender: TObject;
      TheControl: TControl);
    procedure cmpFormDesignerKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure cmpFormDesignerChange(Sender: TObject);
    procedure cmpFormDesignerPlaceComponent(Sender: TObject;
      TheComponent: TComponent);
  private
    { Private declarations }
    procedure UpdateInfo;
  public
    { Public declarations }
  end;

var
  frmDesign: TfrmDesign;

implementation

uses FDCmpPal, OIForm, ToolForm;

{$R *.DFM}

procedure TfrmDesign.UpdateInfo;
begin
  if Assigned(cmpFormDesigner.Control) then
    if cmpFormDesigner.Component is TControl then
      with cmpFormDesigner.Control do
        Caption:=Format(
          'Name: %s; Class: %s; Left: %d; Top: %d; Width: %d; Height: %d',
          [Name,ClassName,Left,Top,Width,Height])
    else
      with cmpFormDesigner.Component do
        Caption:=Format('Name: %s; Class: %s',[Name,ClassName])
  else Caption:='[no selected controls]';
end;

procedure TfrmDesign.FormShow(Sender: TObject);
begin
  cmpFormDesigner.Active:=True;
  with frmObjectInspector do
  begin
    cmbObjectInspector.Root:=Self;
    cmbObjectInspector.Instance:=Self;
    cmpObjectInspector.Root:=Self;
    cmpObjectInspector.Instance:=Self;
    Show;
  end;
end;

procedure TfrmDesign.cmpFormDesignerSelectControl(Sender: TObject;
  TheControl: TControl);
var
  E: Boolean;
begin
  if Assigned(TheControl) then
    {$IFDEF TFD1COMPATIBLE}
    frmToolForm.sbtLock.Down:=cmpFormDesigner.FixedControls.IndexOf(TheControl.Name)<>-1;
    {$ELSE}
    frmTooLForm.sbtLock.Down:=cmpFormDesigner.LockedControls.IndexOf(TheControl.Name)<>-1;
    {$ENDIF}
  UpdateInfo;
  E:=Assigned(cmpFormDesigner.Control);
  with frmToolForm do
  begin
    sbtLock.Enabled:=E;
    sbtAlignToGrid.Enabled:=E;
    sbtAlign.Enabled:=E;
    sbtSize.Enabled:=E;
    sbtDelete.Enabled:=E;
    mniLock.Enabled:=E;
    mniAlignToGrid.Enabled:=E;
    mniDelete.Enabled:=E;
    sbtCopy.Enabled:=E;
    sbtCut.Enabled:=E;
    mniCopy.Enabled:=E;
    mniCut.Enabled:=E;
  end;
end;

procedure TfrmDesign.FormActivate(Sender: TObject);
begin
  ActiveControl:=nil;
  cmpFormDesigner.Update;
end;

procedure TfrmDesign.FormCreate(Sender: TObject);
begin
  cmpFormDesigner.PopupMenu:=frmToolForm.pmnMain;
end;

procedure TfrmDesign.cmpFormDesignerControlDblClick(Sender: TObject;
  TheControl: TControl);
begin
  if Assigned(TheControl) then
  begin
    if TheControl is TComponentContainer then
      ShowMessage('Double-click on '+TComponentContainer(TheControl).Component.Name)
    else ShowMessage('Double-click on '+TheControl.Name);
    ActiveControl:=nil;
  end;
end;

procedure TfrmDesign.cmpFormDesignerKeyDown(Sender: TObject;
  var Key: Word; Shift: TShiftState);
begin
  with frmToolForm do
    case Key of
      VK_INSERT:
        if Shift=[ssShift] then evePaste(nil)
        else
          if Shift=[ssCtrl] then eveCopy(nil);
      VK_DELETE:
        if Shift=[ssShift] then eveCut(nil)
        else
          if Shift=[] then eveDelete(nil);
    end;
end;

procedure TfrmDesign.cmpFormDesignerChange(Sender: TObject);
begin
  UpdateInfo;
end;

procedure TfrmDesign.cmpFormDesignerPlaceComponent(Sender: TObject;
  TheComponent: TComponent);
begin
  EditMode(frmToolForm.pgcMain);
end;

end.
